//
//  EMBSnapLayer.h
//  Ember
//
//  Created by Alan Rogers on 24/07/12.
//  Copyright (c) 2012 Realmac Software. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <CoreGraphics/CoreGraphics.h>

#import "EMBEmberAnnotations/EMBEmberAnnotations-Constants.h"

@interface EMBAnnotation : NSObject <NSCoding>

/*!
	\brief
	The unique object ID for the annotation. Persisted.
 */
@property (readonly, strong, nonatomic) NSString *objectID;
extern NSString * const EMBAnnotationObjectIDKey;

/*!
	\brief
	The version of the annotation. Persisted.
 */
@property (readonly, strong, nonatomic) NSNumber *version;
extern NSString * const EMBAnnotationVersionKey;

/*!
	\brief
	The position of the annotation. Persisted.
 */
@property (assign, nonatomic) CGPoint position;
extern NSString * const EMBAnnotationPositionKey;

/*!
	\brief
	The orientation of the annotation. Persisted.
 */
@property (assign, nonatomic) EMBEmberAnnotationOrientation orientation;
extern NSString * const EMBAnnotationOrientationKey;

/*!
	\brief
	The selection state of the layer for the annotation. When selected, annotation layers usually display a distinct UI. Transient.
 */
@property (assign, getter = isSelected, nonatomic) BOOL selected;
extern NSString * const EMBAnnotationSelectedKey;

/*!
	\brief
	Returns whether an annotation is editable (except positioning). The default implementation returns NO.
 */
- (BOOL)isEditable;

/*!
	\brief
	While `isEqual:` is implement to do a simple check for the objectID this method does a more thourough equality
	check, such as checking the position, orientation and other properties of the annotation.
 */
- (BOOL)isEqualToAnnotation:(EMBAnnotation *)annotation;

@end
