//
//  EMBEmberLibraryConfiguration.h
//  EmberCommon
//
//  Created by Damien DeVille on 16/06/2013.
//  Copyright (c) 2013 Realmac Software. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <TargetConditionals.h>

@interface EMBEmberLibraryConfiguration : NSObject

/*!
	\brief
	The library identifier
 */
@property (copy, nonatomic) NSURL *libraryIdentifier;
extern NSString * const EMBEmberLibraryConfigurationLibraryIdentifier;

/*!
	\brief
	Provides the base location for the library contents when invoked.
 */
@property (copy, nonatomic) NSURL * (^libraryContentsBaseLocationProvider)(NSError **errorRef);
extern NSString * const EMBEmberLibraryConfigurationLibraryContentsBaseLocationProvider;

/*!
	\brief
	Does teardown of the base location when the library is unmounted by stopping accessing security scoped resources for example.
 */
@property (copy, nonatomic) void (^libraryContentsBaseLocationTeardown)(NSURL *location);
extern NSString * const EMBEmberLibraryConfigurationLibraryContentsBaseLocationTeardown;

/*!
	\brief
	The relative path of the library contents location.
 */
@property (copy, nonatomic) NSString *libraryContentsRelativePath;
extern NSString * const EMBEmberLibraryConfigurationLibraryContentsRelativePath;

/*!
	\brief
	The location of the library persistent store.
 */
@property (copy, nonatomic) NSURL *libraryStoreLocation;
extern NSString * const EMBEmberLibraryConfigurationLibraryStoreLocation;

/*!
	\brief
	The options used to mount the persistent store.
 */
@property (strong, nonatomic) NSDictionary *libraryStoreOptions;
extern NSString * const EMBEmberLibraryConfigurationLibraryStoreOptions;

/*!
	\brief
	YES if the library has Ensembles.
 */
@property (assign, nonatomic) BOOL hasEnsembles;
extern NSString * const EMBEmberLibraryConfigurationLibraryHasEnsembles;

/*!
	\brief
	The class for the library manager.
 */
@property (assign, nonatomic) Class fileManagerClass;
extern NSString * const EMBEmberLibraryConfigurationLibraryFileManagerClass;

@end

@interface EMBEmberLibraryConfiguration (Default)

/*!
	\brief
	The default configuraation for the library located in the sandbox container.
 */
+ (EMBEmberLibraryConfiguration *)defaultSandboxContainerConfiguration;

/*!
	\brief
	The default configuration for the library located in the application group container.
 */
#if !TARGET_OS_IPHONE
+ (EMBEmberLibraryConfiguration *)defaultGroupContainerConfiguration;
#endif /* !TARGET_OS_IPHONE */

/*!
	\brief
	The default configuration for the library located in the ubiquitous container.
 */
+ (EMBEmberLibraryConfiguration *)defaultUbiquitousConfiguration;

/*!
	\brief
	The default configuration for the library located in Dropbox using Ensembles.
 */
+ (EMBEmberLibraryConfiguration *)defaultEnsemblesDropboxConfiguration;

/*!
	\brief
	The default configuration for the library located in Dropbox using Ensembles.
 */
+ (EMBEmberLibraryConfiguration *)defaultEnsemblesCloudConfiguration;

/*!
	\brief
	Returns the configuration that matched the given identifier. Returns nil if the identifier does not match any configuration.
 */
+ (EMBEmberLibraryConfiguration *)configurationForIdentifier:(NSURL *)identifier error:(NSError **)errorRef;

@end

extern NSURL *EMBEmberLibraryConfigurationDefaultSandboxContainerLibraryIdentifier(void);
extern NSURL *EMBEmberLibraryConfigurationDefaultGroupContainerLibraryIdentifier(void);
extern NSURL *EMBEmberLibraryConfigurationDefaultUbiquitousLibraryIdentifier(void);
extern NSURL *EMBEmberLibraryConfigurationDefaultEnsemblesCloudLibraryIdentifier(void);
extern NSURL *EMBEmberLibraryConfigurationDefaultEnsemblesDropboxLibraryIdentifier(void);

/*!
	\brief
	Returns YES if two libraries with the same identifier cannot be considered equal.
 */
extern BOOL EMBEmberLibraryConfigurationTransientIdentifier(NSURL *libraryIdentifier);

/*!
	\brief
	Returns YES if the Dropbox application is installed (OS X only).
 */
extern BOOL EMBEmberLibraryConfigurationIsDropboxApplicationInstalled(void);

extern NSString * const EMBEmberLibraryConfigurationLocalDropboxBookmarkDataDefaultKey;
