//
//  EMBBatchImportOperation.h
//  EmberCommon
//
//  Created by Damien DeVille on 15/10/2012.
//  Copyright (c) 2012 Realmac Software. All rights reserved.
//

#import <Foundation/Foundation.h>

#import "EMBEmberCoreConcurrency/EMBEmberCoreConcurrency.h"

@class NSManagedObjectContext;
@class EMBEmberLibrary;

@interface EMBBatchImportOperation : EMBConcurrentOperation <EMBProgressOperation>

- (id)initWithAssetURLs:(NSArray *)assetURLs managedObjectContext:(NSManagedObjectContext *)managedObjectContext emberLibrary:(EMBEmberLibrary *)emberLibrary;

@property (readonly, copy, nonatomic) NSArray *assetURLs;

@property (readonly, copy, atomic) NSArray * (^completionProvider)(NSError **errorRef);

@end

@interface EMBBatchImportOperation (/* Import customization */)

/*!
	\brief
	Use one of the following to customize the snap during import.
	Use `singularSnapsMetadata` to specify a different set of metadata for each imported snap. `singularSnapsMetadata` should have the exact same size as `assetURLs`.
	The single `snapMetadata` takes priority over the more specific one.
 */
@property (strong, nonatomic) NSDictionary *snapMetadata;

@property (strong, nonatomic) NSArray *singularSnapsMetadata;

@property (assign, nonatomic) BOOL replaceExistingItems;

@end
