//
//  RMSnapResult.h
//  RMSnapKit
//
//  Created by Damien DeVille on 11/07/2012.
//

#import <Cocoa/Cocoa.h>

/*!
	\brief
	Wrapper for a snapping operation result, mainly an array of snap images.
 */
@interface RMSnapResult : NSObject

@property (strong, nonatomic) NSArray *media;	// RMSnapMedia

+ (id)snapResultWithMedia:(NSArray *)media;

@end

@interface RMSnapMedia : NSObject

@property (copy, nonatomic) NSString *name;

@end

/*!
	\brief
	Abstract snap image that both screen and web images derives from.
 */
@interface RMSnapImage : RMSnapMedia

@property (strong, nonatomic) NSBitmapImageRep *imageRepresentation;

@end

/*!
	\brief
	A web snap image. Likely to be a full web page grab.
 */
@interface RMWebSnapImage : RMSnapImage

@property (copy, nonatomic) NSURL *URL;
@property (strong, nonatomic) NSData *webArchiveData;

@end

/*!
	\brief
	A screen snap image. Likely to be a complete screen grab.
 */
@class RMScreenSnapWindowLayer;

@interface RMScreenSnapImage : RMSnapImage

@property (copy, nonatomic) NSString *ownerName;

@property (copy, nonatomic) NSNumber *screenIdentifier;
@property (copy, nonatomic) NSString *dockPosition;
@property (copy, nonatomic) NSString *dockPinning;

@property (strong, nonatomic) NSArray *windowLayers;	// RMScreenSnapLayerWindowLayer
- (void)addWindowLayer:(RMScreenSnapWindowLayer *)windowLayer;

@end

/*!
	\brief
	A window layer in a screen snap. Each individual window in a screen snap will be saved as such.
 */
@interface RMScreenSnapWindowLayer : NSObject

@property (copy, nonatomic) NSString *name;
@property (copy, nonatomic) NSString *ownerName;

@property (assign, nonatomic) CGRect frame;
@property (assign, nonatomic) NSInteger level;

@property (strong, nonatomic) NSBitmapImageRep *imageRepresentation;
@property (strong, nonatomic) NSBitmapImageRep *shadowImageRepresentation;

@property (nonatomic) CGPoint cursorHotSpot;	// only if a cursor

@end

@interface RMScreenRecordingMovie : RMSnapMedia

@property (copy, nonatomic) NSURL *movieURL;

@property (copy, nonatomic) NSNumber *screenIdentifier;
@property (copy, nonatomic) NSString *name;

@end
